"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* Runs in a separate process and communicates using process.on('message', ...) */
/* This is because tslint is implemented synchronously */
const fs_1 = require("fs");
const tslint_1 = require("tslint");
let { rules, rulesDirectory } = tslint_1.Linter.loadConfigurationFromPath(`${process.cwd()}/tslint.json`);
let configuration = {
    rules: rules,
    rulesDirectory: rulesDirectory,
    jsRules: undefined,
    defaultSeverity: 'error',
    extends: [],
    linterOptions: {
        typeCheck: true
    }
};
const options = {
    fix: false,
    formatter: 'prose'
};
const fixOptions = {
    fix: true,
    formatter: 'prose'
};
process.on('message', (msg) => {
    let success = true;
    let program = tslint_1.Linter.createProgram(`${process.cwd()}/tslint.json`);
    msg.filesToLint.forEach((fileName) => {
        let linter = new tslint_1.Linter(msg.fix ? fixOptions : options, program);
        let contents = fs_1.readFileSync(fileName, 'utf8');
        linter.lint(fileName, contents, configuration);
        let results = linter.getResult();
        results.failures.forEach((failure) => {
            success = false;
            let response = {
                violation: {
                    fileName,
                    line: failure.getStartPosition().getLineAndCharacter().line + 1,
                    column: failure.getStartPosition().getLineAndCharacter().character,
                    message: failure.getFailure(),
                    hasFix: failure.hasFix()
                }
            };
            process.send(response);
        });
    });
    process.send({ finished: { success } });
});
//# sourceMappingURL=linter-process.js.map