"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../util");
const child_process_1 = require("child_process");
exports.createLinter = (dependencies) => {
    let { logger, bus, git } = dependencies;
    let lintProcess;
    let running = false;
    let rescheduled = false;
    let fix = false;
    let errors = 0;
    let fixable = 0;
    let startLint = () => {
        rescheduled = false;
        running = true;
        git.findChangedFiles().then((files) => {
            files = files.filter(util_1.isTypescriptFile);
            logger.log('linter', `Linting ${files.length} files...`);
            errors = 0;
            fixable = 0;
            let command = {
                fix: fix,
                filesToLint: files
            };
            lintProcess.send(command);
        });
    };
    let lint = () => {
        if (rescheduled) {
            return;
        }
        else if (running) {
            rescheduled = true;
        }
        else {
            startLint();
        }
    };
    let startProcess = () => {
        lintProcess = child_process_1.fork(__dirname + '/linter-process', [], {});
        lintProcess.on('close', (code) => {
            logger.log('linter', `linting process exited with code ${code}`);
        });
        lintProcess.on('message', (response) => {
            if (response.violation) {
                let { fileName, line, column, message, hasFix } = response.violation;
                errors++;
                if (hasFix) {
                    fixable++;
                }
                logger.log('linter', `${util_1.absolutePath(fileName)}:${line}:${column} ${message}`);
            }
            if (response.finished) {
                running = false;
                logger.log('linter', response.finished.success
                    ? 'All files are ok'
                    : `${errors} Linting problems found, ${fixable} ${fix ? 'fixed' : 'fixable'}`);
                bus.signal(response.finished.success ? 'lint-linted' : 'lint-errored');
                if (rescheduled) {
                    startLint();
                }
            }
        });
    };
    return {
        start: (trigger) => {
            startProcess();
            bus.register(trigger, lint);
        },
        stop: () => {
            bus.unregister(lint);
            lintProcess.kill();
            lintProcess = undefined;
        },
        lintOnce: (fixOnce) => {
            fix = fixOnce;
            let isRunning = lintProcess !== undefined;
            if (!isRunning) {
                startProcess();
            }
            return new Promise((resolve) => {
                let ready = () => {
                    bus.unregister(linted);
                    bus.unregister(errored);
                    fix = false;
                    if (!isRunning) {
                        lintProcess.kill();
                        lintProcess = undefined;
                    }
                };
                let linted = () => {
                    ready();
                    resolve(true);
                };
                let errored = () => {
                    ready();
                    resolve(false);
                };
                bus.register('lint-linted', linted);
                bus.register('lint-errored', errored);
                lint();
            });
        }
    };
};
//# sourceMappingURL=linter.js.map