#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const formatter_1 = require("./code-style/formatter");
const linter_1 = require("./code-style/linter");
const compiler_1 = require("./compiler");
const configuration_1 = require("./configuration");
const git_1 = require("./git");
const logger_1 = require("./logger");
const taskrunner_1 = require("./taskrunner");
const mocha_1 = require("./testing/mocha");
const path_1 = require("path");
const injector_1 = require("./injector");
const format_1 = require("./commands/format");
const clean_1 = require("./commands/clean");
const commit_1 = require("./commands/commit");
const release_1 = require("./commands/release");
const assist_1 = require("./commands/assist");
const nyc_1 = require("./testing/nyc");
const bus_1 = require("./bus");
let argsOk = false;
let logger = logger_1.createConsoleLogger();
let taskRunner = path_1.sep === '\\' ? taskrunner_1.createWindowsTaskRunner() : taskrunner_1.createDefaultTaskRunner();
let bus = bus_1.createBus();
let configuration = configuration_1.createConfiguration();
let dependencies = {
    configuration, bus, logger, taskRunner
};
let { inject } = injector_1.createInjector(dependencies);
dependencies.inject = inject;
dependencies.compiler = inject(compiler_1.createCompiler);
dependencies.git = inject(git_1.createGit);
dependencies.formatter = inject(formatter_1.createFormatter);
dependencies.linter = inject(linter_1.createLinter);
dependencies.mocha = inject(mocha_1.createMocha);
dependencies.nyc = inject(nyc_1.createNyc);
/* tslint:disable:no-console */
let success = () => {
    process.exit(0);
};
let failure = (error) => {
    console.error(error);
    process.exit(1);
};
if (process.argv.length === 3) {
    let command = process.argv[2];
    if (command === 'format' || command === 'fix' || command === 'f') {
        argsOk = true;
        inject(format_1.createFixCommand).execute().then(success, failure);
    }
    else if (command === 'commit' || command === 'c') {
        // createCommitCommand: createFixCommand+compile+lint
        argsOk = true;
        inject(commit_1.createCommitCommand).execute().then(success, failure);
    }
    else if (command === 'clean') {
        argsOk = true;
        inject(clean_1.createCleanCommand).execute();
    }
    else if (command === 'release') {
        argsOk = true;
        inject(release_1.createReleaseCommand).execute().then(success, failure);
    }
}
else if (process.argv.length === 2) {
    // Normal operation: keep compiling+checking-createFixCommand+linting
    argsOk = true;
    inject(assist_1.createAssistCommand).execute();
}
if (!argsOk) {
    console.error('Usage: tsa || tsa f[ix] || tsa c[ommit] || tsa release || tsa clean');
    process.exit(1);
}
/* tslint:enable:no-console */
//# sourceMappingURL=index.js.map