"use strict";
// pre-commit makes sure the changed code is formatted and linted.
//
// Rationale:
// - Fixing formatting and linting errors are always fast and easy to fix.
// - This prevents over-complicated merge conflicts
// - This prevents small formatting/linting fix commits
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const helpers_1 = require("../helpers/helpers");
const tsfmt = require("typescript-formatter");
const fs_1 = require("fs");
const path_1 = require("path");
const glob = require("glob");
const bus_1 = require("../../src/bus");
const linter_1 = require("../../src/code-style/linter");
const taskrunner_1 = require("../../src/taskrunner");
const logger_1 = require("../../src/logger");
const git_1 = require("../../src/git");
/* tslint:disable:no-console */
let allTsFiles = () => {
    let tsConfig = JSON.parse(fs_1.readFileSync(path_1.join(process.cwd(), 'tsconfig.json'), 'UTF-8'));
    let globs = tsConfig && tsConfig.include ? tsConfig.include : ['src/**/*.ts', 'test/**/*.ts'];
    let files = [];
    globs.forEach(g => glob.sync(g).forEach(file => files.push(file)));
    return files;
};
let changed = helpers_1.findChangedFiles();
let files = changed.length === 0 ? allTsFiles() : helpers_1.filterTsFiles(changed);
let lintFiles = () => {
    let logger = logger_1.createConsoleLogger();
    let taskRunner = path_1.sep === '\\' ? taskrunner_1.createWindowsTaskRunner() : taskrunner_1.createDefaultTaskRunner();
    let bus = bus_1.createBus();
    let git = git_1.createGit({ taskRunner, logger });
    let linter = linter_1.createLinter({
        taskRunner, logger, bus, git
    });
    return linter.lintOnce(false);
};
tsfmt.processFiles(files, {
    verify: true, replace: false, verbose: false, baseDir: process.cwd(), editorconfig: true, tslint: true, tsfmt: true, tsconfig: true,
    tsconfigFile: undefined, tslintFile: undefined, tsfmtFile: undefined, vscode: false
}).then((resultList) => __awaiter(this, void 0, void 0, function* () {
    let unformattedFiles = [];
    Object.keys(resultList).forEach((key) => {
        let result = resultList[key];
        if (result.error) {
            unformattedFiles.push(result.fileName);
        }
    });
    if (unformattedFiles.length === 0) {
        console.log(`All ${files.length} files were formatted`);
        if (yield lintFiles()) {
            console.log(`All ${files.length} files were linted`);
            process.exit(0);
        }
        else {
            console.log(`There were linting errors`);
            process.exit(1);
        }
    }
    else {
        console.error(`The following files were not formatted:\r\n  ${unformattedFiles.join('\r\n  ')}`);
        process.exit(1);
    }
})).catch((err) => {
    console.error(err);
    process.exit(1);
});
//# sourceMappingURL=pre-commit.js.map